[前][次][番号順一覧][スレッド一覧]

ruby-changes:63434

From: Marc-Andre <ko1@a...>
Date: Mon, 26 Oct 2020 07:10:41 +0900 (JST)
Subject: [ruby-changes:63434] 9c8f0a34df (master): Use 'shareable' with an 'e' [ci skip]

https://git.ruby-lang.org/ruby.git/commit/?id=9c8f0a34df

From 9c8f0a34df3635bfde43a90bbea6a5483dcbde65 Mon Sep 17 00:00:00 2001
From: Marc-Andre Lafortune <github@m...>
Date: Sun, 25 Oct 2020 18:09:51 -0400
Subject: Use 'shareable' with an 'e' [ci skip]


diff --git a/bootstraptest/test_ractor.rb b/bootstraptest/test_ractor.rb
index 782d4fa..6e006b2 100644
--- a/bootstraptest/test_ractor.rb
+++ b/bootstraptest/test_ractor.rb
@@ -420,7 +420,7 @@ assert_equal 'no _dump_data is defined for class Thread', %q{ https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L420
   end
 }
 
 # send sharable and unsharable objects
 assert_equal "ok", %q{
   echo_ractor = Ractor.new do
     loop do
@@ -702,7 +702,7 @@ assert_equal 'ArgumentError', %q{ https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L702
   end
 }
 
 # ivar in sharable-objects are not allowed to access from non-main Ractor
 assert_equal 'can not access instance variables of classes/modules from non-main Ractors', %q{
   class C
     @iv = 'str'
@@ -722,7 +722,7 @@ assert_equal 'can not access instance variables of classes/modules from non-main https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L722
   end
 }
 
 # ivar in sharable-objects are not allowed to access from non-main Ractor
 assert_equal 'can not access instance variables of shareable objects from non-main Ractors', %q{
   shared = Ractor.new{}
   shared.instance_variable_set(:@iv, 'str')
@@ -738,7 +738,7 @@ assert_equal 'can not access instance variables of shareable objects from non-ma https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L738
   end
 }
 
 # But a sharable object is frozen, it is allowed to access ivars from non-main Ractor
 assert_equal '11', %q{
   [Object.new, [], ].map{|obj|
     obj.instance_variable_set('@a', 1)
@@ -750,7 +750,7 @@ assert_equal '11', %q{ https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L750
   }.join
 }
 
 # cvar in sharable-objects are not allowed to access from non-main Ractor
 assert_equal 'can not access class variables from non-main Ractors', %q{
   class C
     @@cv = 'str'
@@ -769,8 +769,8 @@ assert_equal 'can not access class variables from non-main Ractors', %q{ https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L769
   end
 }
 
-# Getting non-sharable objects via constants by other Ractors is not allowed
-assert_equal 'can not access non-sharable objects in constant C::CONST by non-main Ractor.', %q{
+# Getting non-shareable objects via constants by other Ractors is not allowed
+assert_equal 'can not access non-shareable objects in constant C::CONST by non-main Ractor.', %q{
   class C
     CONST = 'str'
   end
@@ -784,7 +784,7 @@ assert_equal 'can not access non-sharable objects in constant C::CONST by non-ma https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L784
   end
 }
 
 # Setting non-sharable objects into constants by other Ractors is not allowed
 assert_equal 'can not set constants with non-shareable objects by non-main Ractors', %q{
   class C
   end
@@ -420,7 +420,7 @@ assert_equal 'no _dump_data is defined for class Thread', %q{ https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L420
 }
 
-# send sharable and unsharable objects
+# send shareable and unshareable objects
 assert_equal "ok", %q{
   echo_ractor = Ractor.new do
@@ -702,7 +702,7 @@ assert_equal 'ArgumentError', %q{ https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L702
 }
 
-# ivar in sharable-objects are not allowed to access from non-main Ractor
+# ivar in shareable-objects are not allowed to access from non-main Ractor
 assert_equal 'can not access instance variables of classes/modules from non-main Ractors', %q{
   class C
@@ -722,7 +722,7 @@ assert_equal 'can not access instance variables of classes/modules from non-main https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L722
 }
 
-# ivar in sharable-objects are not allowed to access from non-main Ractor
+# ivar in shareable-objects are not allowed to access from non-main Ractor
 assert_equal 'can not access instance variables of shareable objects from non-main Ractors', %q{
   shared = Ractor.new{}
@@ -738,7 +738,7 @@ assert_equal 'can not access instance variables of shareable objects from non-ma https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L738
 }
 
-# But a sharable object is frozen, it is allowed to access ivars from non-main Ractor
+# But a shareable object is frozen, it is allowed to access ivars from non-main Ractor
 assert_equal '11', %q{
   [Object.new, [], ].map{|obj|
@@ -750,7 +750,7 @@ assert_equal '11', %q{ https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L750
 }
 
-# cvar in sharable-objects are not allowed to access from non-main Ractor
+# cvar in shareable-objects are not allowed to access from non-main Ractor
 assert_equal 'can not access class variables from non-main Ractors', %q{
   class C
@@ -784,7 +784,7 @@ assert_equal 'can not access non-sharable objects in constant C::CONST by non-ma https://github.com/ruby/ruby/blob/trunk/bootstraptest/test_ractor.rb#L784
 }
 
-# Setting non-sharable objects into constants by other Ractors is not allowed
+# Setting non-shareable objects into constants by other Ractors is not allowed
 assert_equal 'can not set constants with non-shareable objects by non-main Ractors', %q{
   class C
-- 
cgit v0.10.2


--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]